@@ -79,7 +79,7 @@ class Agent(ModelSQL, ModelView):
         pool = Pool()
         Commission = pool.get('commission')
         commission = Commission.__table__()
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
 
         ids = [a.id for a in agents]
         amounts = dict.fromkeys(ids, None)
@@ -335,10 +335,7 @@ class Commission(ModelSQL, ModelView):
             'in': 'out',
             'out': 'in',
             }.get(self.type_)
-        document = 'invoice' if self.amount > 0 else 'credit_note'
-        return (('agent', self.agent),
-            ('type', '%s_%s' % (direction, document)),
-            )
+        return (('agent', self.agent), ('type', direction))
 
     @classmethod
     def get_journal(cls):
@@ -357,7 +354,7 @@ class Commission(ModelSQL, ModelView):
         Invoice = pool.get('account.invoice')
 
         agent = key['agent']
-        if key['type'].startswith('out'):
+        if key['type'] == 'out':
             payment_term = agent.party.customer_payment_term
         else:
             payment_term = agent.party.supplier_payment_term
@@ -381,7 +378,7 @@ class Commission(ModelSQL, ModelView):
         InvoiceLine = pool.get('account.invoice.line')
 
         def sign(commission):
-            if invoice.type.startswith(commission.type_):
+            if invoice.type == commission.type_:
                 return -1
             else:
                 return 1
@@ -390,9 +387,6 @@ class Commission(ModelSQL, ModelView):
         amount = invoice.currency.round(
             sum(c.amount * sign(c) for c in commissions))
 
-        if invoice.type.endswith('credit_note'):
-            amount *= -1
-
         invoice_line = InvoiceLine()
         invoice_line.invoice = invoice
         invoice_line.type = 'line'
